Learn R Programming

WCE (version 1.0.2)

coef.WCE: Obtain estimated coefficients from WCE object

Description

This function extracts the estimated coefficients from a WCE object.

Usage

# S3 method for WCE
coef(object, ...)

Value

The function returns a list with one element if the WCE object was fitted without covariates and two if the WCE object was fitted with covariates. The first element is a matrix of estimated coefficients for the artificial D variables (see Sylvestre and Abrahamowicz, 2009). Each row of the matrix corresponds to a model with the number of knots specified in WCE. The second element of the list is a matrix of estimated covariate coefficients. Similarly, each row of the matrix corresponds to a model with the number of knots specified in WCE.

WCEest

Matrix of estimated coefficients of the artificial D variables.

covariates

Matrix of estimated coefficients of the covariates (optional).

Arguments

object

A WCE object.

...

Optional. Additional arguments to be passed to coef (none currently used).

Author

Marie-Pierre Sylvestre
marie-pierre.sylvestre@umontreal.ca

References

Sylvestre, M. P., & Abrahamowicz, M. (2009). Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Statistics in medicine, 28(27), 3437-3453.

Examples

Run this code
checkWCE(drugdata, id = "Id", event = "Event",  start = "Start", 
		 stop = "Stop", expos = "dose")

wce <- WCE(drugdata, "Cox", 1, 90, constrained = "R", id = "Id", 
		   event = "Event", start = "Start", stop = "Stop", expos = "dose", 
		   covariates = c("age", "sex"))

coef(wce)

Run the code above in your browser using DataLab