Learn R Programming

WCE (version 1.0.2)

drugdata: Sample dataset for use with WCE package

Description

Data to illustrate the use of WCE.

Usage

data("drugdata")

Arguments

Format

A data frame with 77038 observations from 500 individuals. The data frame is formatted in an interval format. Contains 7 variables.

Id

a numeric vector to identify observations that belong to the same individual (Id).

Event

a numeric vector representing the event of interest. Takes the value of 1 in the interval during which the event occurs and is 0 otherwise.

Start

a numeric vector indicating the beginning of the interval.

Stop

a numeric vector indicating the end of the interval.

sex

a numeric vector indicating males (0) and females (1).

age

a numeric vector representing age at baseline.

dose

a numeric vector representing time-dependent doses of a drug.

Details

The variables sex and age are covariates. They are optional and illustrate the inclusion of adjustment variables. Covariates can be numeric or factors.

References

Sylvestre, MP, & Abrahamowicz, M. (2008). Comparison of algorithms to generate event times conditional on time-dependent covariates. Statistics in Medicine, 27(14), 2618-2634.

Examples

Run this code
data(drugdata)

Run the code above in your browser using DataLab