Learn R Programming

WCE (version 1.0.2)

knotsWCE: Obtain the placement of the knots used for splines in WCE models

Description

This function extracts the knots placement for the spline function used to fit the WCE models.

Usage

knotsWCE(x)

Value

Returns a list of vectors indicating the placement of the knots used in the spline function of each of the models fitted in the WCE object.

Arguments

x

A WCE object returned by WCE.

Author

Marie-Pierre Sylvestre
marie-pierre.sylvestre@umontreal.ca

References

Sylvestre, M. P., & Abrahamowicz, M. (2009). Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Statistics in medicine, 28(27), 3437-3453.

Examples

Run this code

wce <- WCE(drugdata, "Cox", 1, 90, constrained = "R", id = "Id", event = "Event",
		   start = "Start", stop = "Stop", expos = "dose", 
		   covariates = c("age", "sex"))

knotsWCE(wce)

Run the code above in your browser using DataLab