summary.WCE: Method to summarize the results of a WCE object
Description
This is a method to summarize the results from either the best fitting or all of the estimated models from a WCE object.
Usage
# S3 method for WCE
summary(object, allres = FALSE, ...)
Value
The summary method prints to screen the estimated coefficients, standard errors and p-values for the coefficients (if any) included in the WCE model. It also provides the partial likelihood and AIC or BIC value, and the number of events used in the estimation of the model.
Arguments
object
A WCE object
...
Optional; other parameters to be passed through to summary.
allres
Logical. If TRUE, then a summary is produced for every model from the WCE object. If FALSE, then a summary is produced only for the best fitting model, as determined by AIC or BIC. Default to FALSE.
Sylvestre MP, Abrahamowicz M. Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Stat Med. 2009 Nov 30;28(27):3437-53.