powered by
This function extracts the knots placement for the spline function used to fit the WCE models.
knotsWCE(x)
Returns a list of vectors indicating the placement of the knots used in the spline function of each of the models fitted in the WCE object.
A WCE object returned by WCE.
WCE
Marie-Pierre Sylvestre marie-pierre.sylvestre@umontreal.ca
Sylvestre, M. P., & Abrahamowicz, M. (2009). Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Statistics in medicine, 28(27), 3437-3453.
wce <- WCE(drugdata, "Cox", 1, 90, constrained = "R", id = "Id", event = "Event", start = "Start", stop = "Stop", expos = "dose", covariates = c("age", "sex")) knotsWCE(wce)
Run the code above in your browser using DataLab