plot.WCE: Plot of the weight function(s) estimated by WCE
Description
Method to plot the weight function(s) of a WCE object. Can plot the best estimated weight function or all the estimated functions simultaneously.
Usage
# S3 method for WCE
plot(x, allres = FALSE, ...)
Arguments
x
A WCE object
allres
Logical. If TRUE, then all the weight functions from the WCE object are plotted simultaneously. If FALSE, then only the best function, determined by AIC or BIC, is plotted. Default to FALSE.
...
Optional. Additional arguments to be passed to plot (none currently used).
Sylvestre MP, Abrahamowicz M. Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Stat Med. 2009 Nov 30;28(27):3437-53.