vcov.WCE: Obtain variance-covariance matrix from WCE models
Description
The vcov method returns the variance-covariance matrix of the estimated regression coefficients from a WCE model.
Usage
# S3 method for WCE
vcov(object, ...)
Value
The function returns variance-covariance matrices with the estimated regression coefficients for the supplied WCE model object. The number of matrices returned is equivalent to the length of the nknots vector (or one matrix, if nknots is a scalar) passed to the WCE function when fitting the model.
Arguments
object
A WCE object.
...
Optional; other parameters to be passed through to vcov (none currently used).
Sylvestre MP, Abrahamowicz M. Flexible modeling of the cumulative effects of time-dependent exposures on the hazard. Stat Med. 2009 Nov 30;28(27):3437-53.